import {
  type Context,
  type APIGatewayProxyResult,
  type APIGatewayEvent,
} from "aws-lambda";
import {
  GameLiftClient,
  CreateGameSessionCommand,
} from "@aws-sdk/client-gamelift";

const maxPlayerSessions = 5;
export const lambdaHandler = async (
  event: APIGatewayEvent,
  context: Context,
): Promise<APIGatewayProxyResult> => {
  const client = new GameLiftClient({});
  const fleetid = process.env.FLEETID;
  const locationname = process.env.LOCATIONNAME;

  // 新規ゲームセッションを作成し、エラーが発生しない場合には 200 を返す
  try {
    const session = await client.send(
      new CreateGameSessionCommand({
        MaximumPlayerSessionCount: maxPlayerSessions,
        FleetId: fleetid,
        Location: locationname,
      }),
    );
    return {
      statusCode: 200,
      body: JSON.stringify({
        GameSession: session,
      }),
    };
  } catch (err) {
    console.log(err);
    return {
      statusCode: 500,
      body: JSON.stringify({
        message: "Cannot get data correctly.",
        details: err,
      }),
    };
  }
};
