import {
  type Context,
  type APIGatewayProxyResult,
  type APIGatewayEvent,
} from "aws-lambda";
import {
  GameLiftClient,
  DescribeGameSessionsCommand,
} from "@aws-sdk/client-gamelift";

export const lambdaHandler = async (
  event: APIGatewayEvent,
  context: Context,
): Promise<APIGatewayProxyResult> => {
  const client = new GameLiftClient({});
  const fleetid = process.env.FLEETID;
  const locationname = process.env.LOCATIONNAME;

  // ゲームセッションを検索し、結果がなくともエラーが発生しない場合には 200 を返す
  try {
    const sessions = await client.send(
      new DescribeGameSessionsCommand({
        FleetId: fleetid,
        Location: locationname,
      }),
    );
    return {
      statusCode: 200,
      body: JSON.stringify({
        AvailableGameSessions: sessions,
      }),
    };
  } catch (err) {
    console.log(err);
    return {
      statusCode: 500,
      body: JSON.stringify({
        message: "Cannot get data correctly.",
        details: err,
      }),
    };
  }
};
