using System;
using System.Collections.Concurrent;
using System.Collections.Generic;
using UnityEngine;

public class GameManager : MonoBehaviour
{

    [NonSerialized] public static GameManager instance;
    [NonSerialized] public bool isSendPlayerPosition;
    [NonSerialized] public bool isInGame;
    
    public GameObject startUpMenuCanvas;
    public ConcurrentQueue<string> OnReceivedMessageQueue = new();
    private Dictionary<string, GameObject> otherPlayers = new();

    private void Awake()
    {
        Application.targetFrameRate = 15;
        instance = GetComponent<GameManager>();
    }

    // インゲーム中は位置情報を送信する
    private void Update()
    {
        if (!isInGame)
            return;
        if (isSendPlayerPosition)
        {
            isSendPlayerPosition = false;
            SendPosition();
        }

        while (OnReceivedMessageQueue.TryDequeue(out var item)) OnReceiveMessage(item);
    }

    // ゲームセッションが選択されたか作成された場合に、取得した情報を使用してゲームサーバーに WebSocket で接続する
    public void OnCompleteRoomSelection(string IPAddress, string Port)
    {
        Debug.Log("Connect to " + IPAddress + " : " + Port);
        WebSocketManager.instance.Connect(IPAddress, Port);
        isInGame = true;
        startUpMenuCanvas.SetActive(false);
    }

    // メッセージ受信時に送信者のプレイヤーIDに応じて画面上のプレイヤーの位置を変更する　
    public void OnReceiveMessage(string message)
    {
        var p = JsonUtility.FromJson<PlayerPosition>(message);
        if (p.senderid == Player.instance.playerid)
            return;

        if (!otherPlayers.ContainsKey(p.senderid))
        {
            var obj = Instantiate(Player.instance.gameObject);
            obj.GetComponent<Player>().Set(false, p.senderid);
            otherPlayers.Add(p.senderid, obj);
        }

        otherPlayers[p.senderid].GetComponent<Player>().UpdatePosition(p.position);
    }


    private void SendPosition()
    {
        var p = new PlayerPosition(Player.instance.playerid, Player.instance.position);
        WebSocketManager.instance.SendWebSocketMessage(JsonUtility.ToJson(p));
    }

    // WebSocketを使用し送受信するプレイヤーの位置情報を定義
    private class PlayerPosition
    {
        public Vector3Int position;
        public string senderid;

        public PlayerPosition(string senderid, Vector3Int position)
        {
            this.senderid = senderid;
            this.position = position;
        }
    }
}