using System;
using UnityEngine;
using UnityEngine.Tilemaps;
using UnityEngine.UI;

public class Player : MonoBehaviour
{
    [SerializeField]
    private bool isMyPlayer = false;
    [SerializeField]
    private Tilemap worldMap;
    [SerializeField]
    private Text playerNameText;
    public Vector3Int position = new Vector3Int(0, 0,0);
    
    public static Player instance;
    
    [NonSerialized]
    public string playerid;
    
    // 操作対象の自分のオブジェクトの場合のみ初期値を設定する
    void Start()
    {
        this.GetComponent<SpriteRenderer>().color = Color.magenta;
        playerNameText.color = Color.magenta;
        if (isMyPlayer)
        {
            playerid = System.Guid.NewGuid().ToString().Substring(0,6);
            playerNameText.color = Color.white;
            playerNameText.text = "Player_" + playerid;
            this.GetComponent<SpriteRenderer>().color = Color.white;
            instance = this.GetComponent<Player>();
        }
    }

    // 外部からプレイヤーを示すイスタンスの情報を更新する
    public void Set(bool isMyPlayer, string playerid)
    {
        this.playerid = playerid;
        this.playerNameText.text = "Player_" + playerid;
        this.isMyPlayer = isMyPlayer;
    }

    // 操作対象の場合のみ、キー入力から位置情報を更新する
    void Update()
    {
        if (GameManager.instance.isInGame == false || !isMyPlayer)
            return;
        
        Vector3Int inputposition = InputMoveDirectionFromKey(position);
        if (Vector3Int.Distance(position, inputposition) > 0)
            GameManager.instance.isSendPlayerPosition = true;
        
        position.x = inputposition.x;
        position.y = inputposition.y;
        UpdatePosition(position);
    }

    public void UpdatePosition(Vector3Int position)
    {
        this.transform.position = worldMap.GetCellCenterWorld(position);
    }
    
    private Vector3Int InputMoveDirectionFromKey(Vector3Int position)
    {

        position.y += (Input.GetKeyDown(KeyCode.UpArrow)) ? 1 : 0;
        position.y += (Input.GetKeyDown(KeyCode.DownArrow)) ? -1 : 0;
        position.x += (Input.GetKeyDown(KeyCode.RightArrow)) ? 1 : 0;
        position.x += (Input.GetKeyDown(KeyCode.LeftArrow)) ? -1 : 0;

        return position;
    }
}
