using System;
using System.Collections;
using UnityEngine;
using UnityEngine.Networking;
using UnityEngine.UI;

public class RestAPIManager : MonoBehaviour
{
    [SerializeField]
    private string apiGatewayDomain = "";
    [SerializeField]
    private string apiKey = "";

    public GameObject ListViewChildButton;
    public GameObject ListView;
    
    
    // JSON から変換するためのデータ構造を定義
    [System.Serializable]
    public class createGameSessionResponse
    {
        public createGameSessionResponseBody GameSession;
    }
    
    [System.Serializable]
    public class createGameSessionResponseBody
    {
        public _GameSession GameSession;
    }

    
    [System.Serializable]
    public class getAvailableGameSessionsResponse
    {
        public _AvailableGameSessions AvailableGameSessions;
    }

    [System.Serializable]
    public class _AvailableGameSessions
    {
        public _GameSession[] GameSessions;
    }

    [System.Serializable]
    public class _GameSession
    {
        public string Name;
        public string IpAddress;
        public string Port;
        public string Status;
        public string CreationTime;
        public string GameSessionId;
    }

    public _GameSession[] GameSessions;

    public void getAvailableGameSessions()
    {
        StartCoroutine(Get("https://" + apiGatewayDomain + "/prod/gamesessions", getAvailableGameSessionsCallback));
    }

    // GameSession検索 API を呼び出し、Active なセッションのみをリスト化して画面に表示
    private void getAvailableGameSessionsCallback(String response)
    {
        getAvailableGameSessionsResponse sessions = JsonUtility.FromJson<getAvailableGameSessionsResponse>(response);
        GameSessions = sessions.AvailableGameSessions.GameSessions;
        
        for (int i = 0; i < GameSessions.Length; i++)
        {
            if (GameSessions[i].Status != "ACTIVE")
                continue;
            GameObject obj = Instantiate(ListViewChildButton, ListViewChildButton.transform.parent);
            obj.GetComponent<ObjectState>().value = i;
            obj.GetComponent<Button>().onClick.AddListener(() =>
            {
                OnGamesessionSelected(obj.GetComponent<ObjectState>().value);
            });
            obj.transform.GetChild(0).GetComponent<Text>().text =
                GameSessions[i].Name;
            obj.transform.GetChild(1).GetComponent<Text>().text =
                GameSessions[i].CreationTime;
            obj.transform.GetChild(2).GetComponent<Text>().text =
                GameSessions[i].IpAddress;
            obj.transform.GetChild(3).GetComponent<Text>().text =
                GameSessions[i].Port;
            
            obj.SetActive(true);
        }

        ListView.SetActive(true);
    }

    public void OnGamesessionSelected(int i)
    {
        
        GameManager.instance.OnCompleteRoomSelection(GameSessions[i].IpAddress, GameSessions[i].Port);
    }

    // GameSession作成 API の呼び出しとコールバックで受け取った JSON を構造体に格納
    public void createGameSession()
    {
        StartCoroutine(Put("https://" + apiGatewayDomain + "/prod/gamesession", createGameSessionCallback));
    }

    private void createGameSessionCallback(String response)
    {
        createGameSessionResponse session = JsonUtility.FromJson<createGameSessionResponse>(response);
        GameManager.instance.OnCompleteRoomSelection(session.GameSession.GameSession.IpAddress, session.GameSession.GameSession.Port);
    }
    
    // GET API を実行
    public IEnumerator Get(String url, Action<String> callback)
    {
        var request = new UnityWebRequest();
        request.downloadHandler = new DownloadHandlerBuffer();
        request.url = url;
        request.SetRequestHeader("x-api-key", apiKey);
        request.SetRequestHeader("Content-Type", "application/json; charset=UTF-8");
        request.method = UnityWebRequest.kHttpVerbGET;
        yield return request.SendWebRequest();

        if (request.result == UnityWebRequest.Result.ConnectionError)
        {
            Debug.Log(request.error);
        }
        else
        {
            if (request.responseCode == 200)
            {
                Debug.Log("success");
                callback(request.downloadHandler.text);
            }
            else
            {
                Debug.Log("failed");
            }
        }
    }

    // PUT API を実行
    public IEnumerator Put(String url, Action<String> callback)
    {
        var request = new UnityWebRequest();
        request.downloadHandler = new DownloadHandlerBuffer();
        request.url = url;
        request.SetRequestHeader("x-api-key", apiKey);
        request.SetRequestHeader("Content-Type", "application/json; charset=UTF-8");
        request.method = UnityWebRequest.kHttpVerbPUT;
        yield return request.SendWebRequest();

        if (request.result == UnityWebRequest.Result.ConnectionError)
        {
            Debug.Log(request.error);
        }
        else
        {
            if (request.responseCode == 200)
            {
                callback(request.downloadHandler.text);
            }
            else
            {
                Debug.Log("failed");
            }
        }
    }
}