package main

import (
	"aws/amazon-gamelift-go-sdk/model"
	"aws/amazon-gamelift-go-sdk/server"
	"log"
	"os"
)

type gameProcess struct {
	Port            int
	GameSessionLogs server.LogParameters
}

// GameSession開始を受信するコールバック
func (g gameProcess) OnStartGameSession(model.GameSession) {
	log.Println("[GameLift]Callback: OnStartGameSession")
	err := server.ActivateGameSession()
	if err != nil {
		log.Fatal(err.Error())
	}
}

// GameSession更新を受信するコールバック
func (g gameProcess) OnUpdateGameSession(model.UpdateGameSession) {
	log.Println("[GameLift]Callback: OnUpdateGameSession")
}

// プロセス終了を受信するコールバック
func (g gameProcess) OnProcessTerminate() {
	log.Println("[GameLift]Callback: OnProcessTerminate")
	err := server.ProcessEnding()
	if err != nil {
		os.Exit(0)
	}

	defer server.Destroy()
}

// GameLift からヘルスチェック受信するコールバック
func (g gameProcess) OnHealthCheck() bool {
	log.Println("[GameLift]Callback: OnHealthCheck")
	return true
}

func gameliftServerSDKDestroy() {
	defer server.Destroy()
}

// GameLift Server SDK を init し、正常に成功した場合 processReady で GameLift に伝える
func gameliftServerSDKSetup(websocketurl string, processid string, hostid string, fleetid string, authtoken string, port int) {
	var param server.ServerParameters = server.ServerParameters{
		WebSocketURL: websocketurl,
		ProcessID:    processid,
		HostID:       hostid,
		FleetID:      fleetid,
		AuthToken:    authtoken,
	}
	process := gameProcess{
		Port: port,
	}

	log.Print("[GameLift]:Invoke initSDK")
	err := server.InitSDK(param)
	if err != nil {
		log.Fatal(err.Error())
	}

	log.Print("[GameLift]:Invoke processReady")
	err = server.ProcessReady(server.ProcessParameters{
		OnStartGameSession: process.OnStartGameSession,
		OnProcessTerminate: process.OnProcessTerminate,
		OnHealthCheck:      process.OnHealthCheck,
		Port:               process.Port,
	})

	if err != nil {
		log.Fatal(err.Error())
	}

}
